local lazypath = vim.fn.stdpath('data') .. '/lazy/lazy.nvim'

if not vim.loop.fs_stat(lazypath) then
	vim.fn.system({
		'git',
		'clone',
		'--filter=blob:none',
		'https://github.com/folke/lazy.nvim.git',
		'--branch=stable', -- latest stable release
		lazypath,
	})
end

vim.opt.rtp:prepend(lazypath)

require('lazy').setup({

	'EdenEast/nightfox.nvim',
	'luckasRanarison/tree-sitter-hypr',

	'lambdalisue/nerdfont.vim',
	'gelguy/wilder.nvim',

	'bkad/camelcasemotion',
	'lewis6991/gitsigns.nvim',

	{
		'nvim-telescope/telescope.nvim',
		tag = '0.1.8',
		dependencies = {
			'nvim-lua/plenary.nvim'
		}
	},

	{
		'stevearc/oil.nvim',
		dependencies = {
			'nvim-tree/nvim-web-devicons'
		},
	},

	{
		'kylechui/nvim-surround',
		version = '*', -- Use for stability; omit to use `main` branch for the latest features
		config = function()
			require('nvim-surround').setup()
		end
	},

	{
		'OXY2DEV/markview.nvim',
		config = function()
			require('markview').setup()
		end,
		dependencies = {
			-- You may not need this if you don't lazy load
			-- Or if the parsers are in your $RUNTIMEPATH
			"nvim-treesitter/nvim-treesitter",

			"nvim-tree/nvim-web-devicons"
		},
	},

	{
		'shellRaining/hlchunk.nvim',
		event = {
		'UIEnter'
	},
	},

	{
		'ThePrimeagen/harpoon',
		branch = 'harpoon2',
		dependencies = {
			'nvim-lua/plenary.nvim'
		}
	},

	{
		'nvim-lualine/lualine.nvim',
		dependencies =
		{
			'nvim-tree/nvim-web-devicons',
			opt = true
		}
	},

	{
		'nvim-treesitter/nvim-treesitter',
		build = ':TSUpdate'
	},

	{
		'VonHeikemen/lsp-zero.nvim',
		branch = 'v3.x',
		dependencies = {
			-- LSP Support
			'neovim/nvim-lspconfig',
			'williamboman/mason.nvim',
			'williamboman/mason-lspconfig.nvim',

			-- Autocompletion
			'hrsh7th/nvim-cmp',
			'hrsh7th/cmp-nvim-lsp',
			'L3MON4D3/LuaSnip',
		}
	},

	{
		'echasnovski/mini.nvim',
		version = false
	},
})

vim.opt.laststatus=2
